import modelling
from modelling import *


if __name__ == '__main__':
	print('''
		=================================
		Module Written by Santo K. Thomas
		=================================
		email: santokalayil@gmail.com
		phone: +91 8891960880
		Address:
			Kalayil House
			Cheenkalthadom P.O,
			Mannarakulanji, 
			Pathanamthitta
		''')